History
=======

1.5.2 (10/15/2016)
------------------

 - Exception logging bugfixes.
 - Dropped support for Python 2.6.
 - General code formatting improvements.


1.5.1 (03/05/2015)
------------------

 - Regression fixes.


1.5.0 (03/05/2015)
------------------

 - Use unicode exclusively.
 - Update length limits on message strings.
 - Add support for HTML messages.
 - Improve timezone support when pytz is unavailable.
 - Remove requests dependency.
 - Improve documentation.


1.4.0 (05/31/2014)
------------------

 - Add new Pushover priority: LOWEST.
 - Add Application.{limit,remaining,reset} to track message allotment.
 - Fix title and message length validation.


1.3.2 (05/16/2014)
------------------

 - Fix dependency issues when installing.


1.3.1 (09/30/2013)
------------------

 - Updated authentication checks for new API responses.


1.3.0 (09/01/2013)
------------------

 - Added Python 2.6 support.


1.2.1 (09/01/2013)
------------------

 - Bugfixes.


1.2.0 (08/30/2013)
------------------

 - Renamed classes.


1.1.0 (08/30/2013)
------------------

 - Added Python 3 support.


1.0.0 (08/30/2013)
------------------

 - API overhaul and "completion".


0.1.0 (08/28/2013)
------------------

 - Initial release.
